import logging

import click

import pyconza2014

log = logging.getLogger(__name__)


@click.command()
@click.option('--count', default=1, help='Number of greetings.')
@click.option('--name', prompt='Your name', help='The person to greet.')
@click.option('--debug', default=False, help='Debug mode.')
def main(count, name, debug):
    """Simple program that greets NAME for a total of COUNT times."""
    logging.basicConfig(level=logging.DEBUG if debug else logging.INFO)

    for x in range(count):
        click.echo('Hello %s!' % name)

    log.debug('Goodbye %s!' % name)


import re
from setuptools import setup

init_py = open('pyconza2014/__init__.py').read()
metadata = dict(re.findall("__([a-z]+)__ = '([^']+)'", init_py))
metadata['doc'] = re.findall('"""(.+)"""', init_py)[0]

setup(
    name='pyconza2014',
    version=metadata['version'],
    description=metadata['doc'],
    author=metadata['author'],
    author_email=metadata['email'],
    url=metadata['url'],
    packages=['pyconza2014'],
    include_package_data=True,
    install_requires=[
        'click < 2.1.0'
    ],
    entry_points={
        'console_scripts': [
            'pyconza2014 = pyconza2014.cli:main',
        ],
    },
    test_suite='nose.collector',
    license=open('LICENSE').read(),
)



"""PyConZA 2014 Demo"""

__author__ = 'Michael Joseph'
__email__ = 'michaeljoseph@gmail.com'
__url__ = 'https://github.com/michaeljoseph/pyconza2014'
__version__ = '0.1.0'


def pyconza2014():
    return 'Hello World!'
